Crate co_storage

Crate co_storage 

Modules

request

Structs

BlockStat
ChangeBlockStorage
Store all Cid of blocks that have been newly created or removed. Additionally set calls for blocks which already exists in next will be ignored.
EncryptedBlockStorage
EncryptedBlockStorageMapping
ExtendedBlock
ExtendedBlockOptions
JoinBlockStorage
Joins multiple block storages together. Write operations will be always delegated to the first storage (which passed to new). Read operations starts with the last up to the first.
LinksBlockStorage
A BlockStorage which verfies all links exist when create a new block.
MappedBlockStorage
Maps certain CID codecs to mapped CIDs using BlockStorageContentMapping.
MemoryBlockStorage
MemoryStorage
PinOptions
Secret
Stores a secrent and ensures it will only be showen using the divulge method. Display and debug traits are implemented and will only show masked keys.
StaticBlockStorage
Block storage implementation for static data.
StoreParamsBlockStorage
This storage implementation converts block storeparams. If an conversation is not possible StorageError::InvalidArgument is retuned.

Enums

Algorithm
AlgorithmError
BlockStorageChange
EncryptionReferenceMode
PinKind
StorageError

Traits

BlockStorage
BlockStorageContentMapping
Map Cids between mappend and plain.
BlockStorageExt
ExtendedBlockStorage
PinApi
Storage Pin API.
Storage
Storage interface.
StorageContentMapping

Functions

node_reader