#[repr(u8)]pub enum Algorithm {
XChaCha20Poly1305 = 1,
}Variants
XChaCha20Poly1305 = 1
Implementations
Sourceimpl Algorithm
impl Algorithm
Sourcepub fn nonce_size(&self) -> usize
pub fn nonce_size(&self) -> usize
Cipher algorithm nonce size in bytes.
Sourcepub fn generate_serect(&self) -> Secret
pub fn generate_serect(&self) -> Secret
Generate a random secret key suitable for the cipher algorithm.
Sourcepub fn generate_nonce(&self) -> Vec<u8> ⓘ
pub fn generate_nonce(&self) -> Vec<u8> ⓘ
Generate a random nonce suitable for the cipher algorithm.