EncryptionReferenceMode

Enum EncryptionReferenceMode 

pub enum EncryptionReferenceMode {
    DisallowPlain,
    DisallowPlainExcept(BTreeSet<Cid>),
    DisallowExcept(BTreeSet<Cid>),
    AllowPlain,
    AllowPlainIfExists,
    Warning,
}

Variants



DisallowPlain

Disallow any references that are not encrypted. Allowed references:

  • Plain: NO
  • Unrelated encrypted: YES
  • CoReference: YES


DisallowPlainExcept(BTreeSet<Cid>)

Disallow any references that are not encrypted except specific plain references. Unrelated encrypted references are allowed. Allowed references:

  • Plain: SPECIFIC
  • Unrelated encrypted: YES
  • CoReference: YES


DisallowExcept(BTreeSet<Cid>)

Disallow any references that are not encrypted except specific references. Allowed references:

  • Plain: SPECIFIC
  • Unrelated encrypted: SPECIFIC
  • CoReference: YES


AllowPlain

Allow any plain references. Allowed references:

  • Plain: YES
  • Unrelated encrypted: YES
  • CoReference: YES


AllowPlainIfExists

Allow any plain references if the exists in parent storage. Allowed references:

  • Plain: IF EXISTS
  • Unrelated encrypted: YES
  • CoReference: YES


Warning

Allow any plain references but warn (log) about unencrypted references. Allowed references:

  • Plain: YES, WITH WARNING
  • Unrelated encrypted: YES
  • CoReference: YES

Implementations

Source

impl EncryptionReferenceMode

pub async fn is_reference_allowed<S>( &self, next: &S, reference: Cid, parent: Cid, ) -> bool
where S: BlockStorage,

Test if reference is allowed in parent.

Note: For mode Warning, the caller is responsible for the warning.