pub enum StorageError {
NotFound(Cid<64>, Error),
Internal(Error),
InvalidArgument(Error),
}Variants
NotFound(Cid<64>, Error)
Block not found error. This error is may be temporarily as the block may comes available on the network.
Internal(Error)
Internal storage error. This indicates some invalid state and is not be retriable with same parameters.
InvalidArgument(Error)
Invalid argument passes to call or storage configuration. This is not be retriable with same parameters.