pub struct ChangeBlockStorage<S> { /* private fields */ }Expand description
Store all Cid of blocks that have been newly created or removed.
Additionally set calls for blocks which already exists in next will be ignored.
Implementations
Sourceimpl<S> ChangeBlockStorage<S>
impl<S> ChangeBlockStorage<S>
pub fn new(next: S) -> Self
pub fn set_record(&mut self, record: bool)
Sourcepub async fn drain(&self) -> impl Iterator<Item = BlockStorageChange> + use<S>
pub async fn drain(&self) -> impl Iterator<Item = BlockStorageChange> + use<S>
Drain all changes and return them as iterator.