pub struct EncryptedBlockStorage<S> { /* private fields */ }Implementations
Sourceimpl<S> EncryptedBlockStorage<S>where
S: AnyBlockStorage,
impl<S> EncryptedBlockStorage<S>where
S: AnyBlockStorage,
pub fn new( next: S, key: Secret, algorithm: Algorithm, mapping: EncryptedBlockStorageMapping, ) -> Self
pub fn with_encryption_reference_mode( self, mode: EncryptionReferenceMode, ) -> Self
Sourcepub fn set_storage(&mut self, next: S)
pub fn set_storage(&mut self, next: S)
Set next storage.
Sourcepub async fn insert_mappings(
&self,
mappings: impl IntoIterator<Item = MappedCid>,
)
pub async fn insert_mappings( &self, mappings: impl IntoIterator<Item = MappedCid>, )
Add known mappings.
Sourcepub async fn load_mapping(&self, map: &Cid) -> Result<(), StorageError>
pub async fn load_mapping(&self, map: &Cid) -> Result<(), StorageError>
Load mapping from CID. This will add the mappings to the existing.
Sourcepub async fn flush_mapping(&self) -> Result<Option<Cid>, StorageError>
pub async fn flush_mapping(&self) -> Result<Option<Cid>, StorageError>
Flush mapping to (parent) storage. Returns the encrypted mapping CID. The mapping tree will also only link to encrypted CIDs.
Sourcepub async fn clear_mapping(&self, keep: impl IntoIterator<Item = Cid>)
pub async fn clear_mapping(&self, keep: impl IntoIterator<Item = Cid>)
Clear encryption mapping.
Sourcepub async fn regenerate_mapping(
&mut self,
cids: impl Iterator<Item = Cid>,
) -> Result<Option<Cid>, StorageError>
pub async fn regenerate_mapping( &mut self, cids: impl Iterator<Item = Cid>, ) -> Result<Option<Cid>, StorageError>
This will regenerate and flush the encryption block mapping using supplied CIDs.
Sourcepub async fn insert_mapping(
&self,
encrypted: &Cid,
plain: Option<&Cid>,
) -> Result<bool, StorageError>
👎Deprecated
pub async fn insert_mapping( &self, encrypted: &Cid, plain: Option<&Cid>, ) -> Result<bool, StorageError>
Insert mapping for encrypted block. Returns true if mapping has been changed.
Sourcepub async fn get_unencrypted(&self, cid: &Cid) -> Result<Block, StorageError>
pub async fn get_unencrypted(&self, cid: &Cid) -> Result<Block, StorageError>
Get encrypted cid as unencrypted block.
Sourcepub async fn set_encrypted(&self, block: Block) -> Result<Cid, StorageError>
pub async fn set_encrypted(&self, block: Block) -> Result<Cid, StorageError>
Set encrypted block. Expects the encrypted block belongs to our key.
Errors:
StorageError::InvalidArgument: Block can not be decrypted.