pub struct Secret(/* private fields */);Expand description
Stores a secrent and ensures it will only be showen using the divulge method. Display and debug traits are implemented and will only show masked keys.
Implementations