pub struct JoinBlockStorage<S, R> { /* private fields */ }Expand description
Joins multiple block storages together.
Write operations will be always delegated to the first storage (which passed to new).
Read operations starts with the last up to the first.
Implementations
Sourceimpl<S, R> JoinBlockStorage<S, R>where
S: BlockStorage + 'static,
R: ExtendedBlockStorage + 'static,
impl<S, R> JoinBlockStorage<S, R>where
S: BlockStorage + 'static,
R: ExtendedBlockStorage + 'static,